@@ -13,7 +13,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2010 XNeur Team
  *
  */
 
@@ -23,8 +23,10 @@
 #define NO_LANGUAGE	-1
 
 #include "buffer.h"
+#include "xneur.h"
 
-int check_lang(struct _buffer *p, int cur_lang);
-int get_next_lang(int cur_lang);
+int check_lang(struct _xneur_handle *handle, struct _buffer *p, int cur_lang);
+
+int check_lang_with_similar_words(struct _xneur_handle *handle, struct _buffer *p, int cur_lang);
 
 #endif /* _DETECTION_H_ */
