@@ -13,7 +13,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2010 XNeur Team
  *
  */
 
@@ -41,7 +41,7 @@ static int get_max_path_len(void)
 	return max_path_len;
 }
 
-static char* get_file_content(const char *file_name)
+char* get_file_content(const char *file_name)
 {
 	struct stat sb;
 
@@ -88,13 +88,8 @@ char* get_file_path_name(const char *dir_name, const char *file_name)
 
 	// Search by only full path
 	strcpy(path_file, file_name);
-
-	FILE *stream = fopen(path_file, "r");
-	if (stream != NULL)
-	{
-		fclose(stream);
+	if (strstr(path_file, "/") != NULL)
 		return path_file;
-	}
 
 	// Search conf in ~/.xneur
 	if (dir_name == NULL)
@@ -102,7 +97,7 @@ char* get_file_path_name(const char *dir_name, const char *file_name)
 	else
 		snprintf(path_file, max_path_len, "%s/%s/%s/%s", getenv("HOME"), HOME_CONF_DIR, dir_name, file_name);
 
-	stream = fopen(path_file, "r");
+	FILE *stream = fopen(path_file, "r");
 	if (stream != NULL)
 	{
 		fclose(stream);
@@ -137,11 +132,13 @@ char* get_home_file_path_name(const char *dir_name, const char *file_name)
 	}
 	else
 	{
+		snprintf(path_file, max_path_len, "%s/%s", getenv("HOME"), HOME_CONF_DIR);
+		mkdir(path_file, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
+		
 		char *dir = strdup(dir_name);
 		char *dir_part = strsep(&dir, DIR_SEPARATOR);
 		snprintf(path_file, max_path_len, "%s/%s/%s", getenv("HOME"), HOME_CONF_DIR, dir_part);
 		mkdir(path_file, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
-
 		while (dir != NULL)
 		{
 			path_file = strcat(path_file, DIR_SEPARATOR); 
@@ -152,7 +149,6 @@ char* get_home_file_path_name(const char *dir_name, const char *file_name)
 		free(dir_part);
 		
 		mkdir(path_file, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
-		
 		snprintf(path_file, max_path_len, "%s/%s/%s/%s", getenv("HOME"), HOME_CONF_DIR, dir_name, file_name);
 	}
 	return path_file;
