@@ -13,19 +13,22 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2010 XNeur Team
  *
  */
 
 #ifndef _BIND_TABLE_H_
 #define _BIND_TABLE_H_
 
-#include <X11/Xutil.h>
+#include <X11/XKBlib.h>
 
 void bind_manual_actions(void);
 void bind_user_actions(void);
 void unbind_user_actions(void);
 
+void grab_manual_action(void);
+void grab_user_action(void);
+
 enum _hotkey_action get_manual_action(KeySym key_sym, int mask);
 int get_user_action(KeySym key_sym, int mask);
 
