@@ -13,7 +13,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
@@ -21,11 +21,11 @@
 #define _DEFINES_H_
 
 #define INPUT_HANDLE_MASK	PropertyChangeMask
-#define EVENT_KEY_MASK		KeyPressMask | KeyReleaseMask
+#define EVENT_KEY_MASK		KeyPressMask|KeyReleaseMask
 #define EVENT_PRESS_MASK	KeyPressMask
 #define EVENT_RELEASE_MASK	KeyReleaseMask
-#define FOCUS_CHANGE_MASK	FocusChangeMask | LeaveWindowMask | EnterWindowMask
-#define BUTTON_HANDLE_MASK	ButtonPressMask
+#define FOCUS_CHANGE_MASK   FocusChangeMask|LeaveWindowMask|EnterWindowMask
+#define BUTTON_HANDLE_MASK	ButtonPressMask|ButtonReleaseMask
 
 static const int groups[4] = {0x00000000, 0x00002000, 0x00004000, 0x00006000};
 
