@@ -13,19 +13,17 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
 #ifndef _SWITCHLANG_H_
 #define _SWITCHLANG_H_
 
-int  get_active_keyboard_group(void);
-int  get_cur_lang(void);
-void switch_lang(int new_lang);
-void switch_group(int new_group);
-int  get_keyboard_groups_count(void);
-int  print_keyboard_groups(void);
-void set_next_keyboard_group(void);
+#include "xneur.h"
+
+int  get_curr_keyboard_group(void);
+void set_next_keyboard_group(struct _xneur_handle *handle);
+void set_prev_keyboard_group(struct _xneur_handle *handle);
 
 #endif /* _SWITCHLANG_H_ */
