@@ -13,7 +13,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
@@ -22,25 +22,29 @@
 
 #include <X11/Xutil.h>
 
+#include "xneur.h"
+
 struct _window
 {
+	struct _xneur_handle *handle;
+	
 	struct _keymap *keymap;
 
 	Display *display;
 	Window window;
 
-	Window flag_window;
-
-	Atom close_atom;
-	Atom protocols_atom;
+	Atom internal_atom;
 
+	int _NET_SUPPORTED;
+	
 	int  (*create) (struct _window *p);
 	void (*destroy) (struct _window *p);
 	void (*move_window) (struct _window *p, int x, int y);
 	int  (*init_keymap) (struct _window *p);
+	void (*uninit_keymap) (struct _window *p);
 	void (*uninit) (struct _window *p);
 };
 
-struct _window* window_init(void);
+struct _window* window_init(struct _xneur_handle *handle);
 
 #endif /* _WINDOW_H_ */
