@@ -13,7 +13,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
@@ -77,8 +77,19 @@ static int get_add_id(struct _list_char *list, const char *string)
 
 static int find_id(struct _list_char *list, const char *string, int mode)
 {
+	if (list->data_count == 0)
+		return -1;
+	
 	if (mode == BY_PLAIN)
 	{
+		// Print all list for debug
+		/*for (int i = 0; i < list->data_count - 1; i++)
+		{
+			struct _list_char_data *data = &list->data[0];
+			data = &list->data[i];
+			log_message (ERROR, "%d %s", i, data->string);
+		}*/ 
+		
 		int first = 0;
 		int last = list->data_count - 1;
 
@@ -101,13 +112,38 @@ static int find_id(struct _list_char *list, const char *string, int mode)
 
 	if (mode == BY_REGEXP)
 	{
+		int len = 0;
+
 		for (int i = 0; i < list->data_count; i++)
 		{
 			struct _list_char_data *data = &list->data[i];
-
-			if (check_regexp_match(string, data->string) != NULL)
-				return i;
+			len += strlen(data->string) + 2;
 		}
+
+		char *full_str = malloc(len * sizeof(char));
+		full_str[0] = '\0';
+
+		for (int i = 0; i < list->data_count - 1; i++)
+		{
+			struct _list_char_data *data = &list->data[0];
+			data = &list->data[i];
+			strcat(full_str, data->string);
+			strcat(full_str, "|");
+		} 
+
+		struct _list_char_data *data;
+		data = &list->data[list->data_count - 1];
+		strcat(full_str, data->string);			
+
+		if (check_regexp_match(string, full_str))
+		{
+			if (full_str != NULL)
+				free(full_str);
+			return 1;
+		}
+
+		if (full_str != NULL)
+			free(full_str);
 	}
 
 	return -1;
@@ -172,10 +208,33 @@ struct _list_char_data* list_char_find_alike(struct _list_char *list, const char
 
 	if (strncmp(list->data[id].string, string, strlen(string)) != 0)
 		return NULL;
-	
+
 	return &list->data[id];
 }
 
+struct _list_char* list_char_alike(struct _list_char *list, const char *string)
+{
+	if (strlen(string) < 4)
+		return NULL;
+	
+	int id = get_add_id(list, string);
+	if ((id == -1) || (id == list->data_count))
+		return NULL;
+
+	if (strncmp(list->data[id].string, string, strlen(string)) != 0)
+		return NULL;
+
+	struct _list_char* list_alike = list_char_init();
+	
+	for (int i = id; i < list->data_count; i++)
+	{
+		if (strncmp(list->data[i].string, string, strlen(string)) != 0)
+			break;
+		add_last(list_alike, list->data[i].string);
+	}
+	return list_alike;
+}
+
 int list_char_exist(struct _list_char *list, const char *string, int mode)
 {
 	struct _list_char_data *data = list->find(list, string, mode);
@@ -325,6 +384,7 @@ void list_char_uninit(struct _list_char *list)
 
 	free(list->data);
 	free(list);
+	list = NULL;
 }
 
 struct _list_char* list_char_init(void)
@@ -332,6 +392,8 @@ struct _list_char* list_char_init(void)
 	struct _list_char *list = (struct _list_char *) malloc(sizeof(struct _list_char));
 	bzero(list, sizeof(struct _list_char));
 
+	list->data_count = 0;
+	
 	list->uninit	= list_char_uninit;
 	list->add	= list_char_add;
 	list->rem	= list_char_rem;
@@ -340,6 +402,7 @@ struct _list_char* list_char_init(void)
 	list->load	= list_char_load;
 	list->save	= list_char_save;
 	list->clone	= list_char_clone;
+	list->alike	= list_char_alike;
 	list->sort	= list_char_sort;
 	list->exist	= list_char_exist;
 	return list;
