@@ -13,7 +13,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
@@ -27,7 +27,7 @@
 
 #include "log.h"
 
-static int LOG_LEVEL = DEBUG;
+static int LOG_LEVEL = TRACE;
 
 void log_set_level(int level)
 {
@@ -70,6 +70,11 @@ void log_message(int level, const char *string, ...)
 			modifier = BLUE_COLOR "[TRA] " NORMAL_COLOR;
 			break;
 		}
+		case NONE:
+		{
+			modifier = "[NON] ";
+			break;
+		}
 	}
 
 	time_t curtime = time(NULL);
@@ -81,6 +86,7 @@ void log_message(int level, const char *string, ...)
 		char *tb = malloc(256 * sizeof(char));
 		strftime(tb, 256, "%T", loctime);
 		sprintf(time_buffer, "%s ", tb);
+		free(tb);
 	}
 
 	int len = strlen(string) + strlen(modifier) + strlen(time_buffer) + 3;
