@@ -13,7 +13,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
@@ -21,9 +21,7 @@
 #  include "config.h"
 #endif
 
-#ifdef WITH_PCRE
-#  include <pcre.h>
-#endif
+#include <pcre.h>
 
 #include <string.h>
 #include <stdio.h>
@@ -31,21 +29,18 @@
 #include "types.h"
 #include "log.h"
 
-#ifdef WITH_PCRE
-
-char* check_regexp_match(const char *str, const char *pattern)
+int check_regexp_match(const char *str, const char *pattern)
 {
 	int options = PCRE_UTF8;
 	const char *error;
 	int erroffset;
 
 	const unsigned char *tables = pcre_maketables();
-
 	pcre *re = pcre_compile(pattern, options, &error, &erroffset, tables);
 	if (!re)
 	{
 		log_message(ERROR, _("Can't compile regular expression '%s'"), pattern);
-		return NULL;
+		return FALSE;
 	}
 
 	int str_len = strlen(str);
@@ -56,40 +51,23 @@ char* check_regexp_match(const char *str, const char *pattern)
 	{
 		log_message(ERROR, _("Can't exec regular expression '%s', eror code %d"), pattern, count);
 		pcre_free(re);
+		pcre_free((void*)tables);
 		return FALSE;
 	}
 
 	pcre_free(re);
-
-	if (count == PCRE_ERROR_NOMATCH)
-		return NULL;
+	pcre_free((void*)tables);
 	
-	/*for(int i = 0; i < count; i++)
-	{
-		printf("%i substring - '", i);
-
-		for(int j=ovector[i*2]; j < ovector[i*2+1]; j++) 
-		    putchar(str[j]);
-		putchar('\''); putchar('\n');
-	}*/
+	if (count == PCRE_ERROR_NOMATCH)
+		return FALSE;
 	
 	const char *pcre_string = NULL;
 	if(pcre_get_substring(str, ovector, count, 0, &pcre_string) < 0)
-		return NULL;
+		return FALSE;
 
-	char *return_string = strdup(pcre_string);
+	//log_message(TRACE, _("Match word '%s' and PERL pattern '%s'"), str, pattern);
 	
 	pcre_free_substring(pcre_string);
-
-	return return_string;
+		
+	return TRUE;
 }
-
-#else
-
-int check_regexp_match(const char *str, const char *pattern)
-{
-	if (str || pattern){}
-	return NULL;
-}
-
-#endif
