@@ -13,7 +13,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
@@ -27,5 +27,10 @@ int   trim_word(char *word, int len);
 void  lower_word_inplace(char *word);
 char* lower_word(const char *word, int len);
 char* str_replace(const char *source, const char *search, const char *replace);
+char* real_sym_to_escaped_sym(const char *source);
+char* escaped_sym_to_real_sym(const char *source);
+void  del_final_numeric_char(char *word);
+int levenshtein(const char *s, const char *t);
+int damerau_levenshtein(const char *string1, const char *string2, int w, int s, int a, int d);
 
 #endif /* _TEXT_H_ */
