@@ -13,7 +13,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
@@ -22,9 +22,21 @@
 #ifndef _TYPES_H_
 #define _TYPES_H_
 
+#ifndef TRUE
 #define TRUE		1
+#endif
+
+#ifndef FALSE
 #define FALSE		0
+#endif
 
 #define NULLSYM		0
 
+#define DICT_NAME			"dictionary"
+#define PROTO_NAME			"proto"
+#define BIG_PROTO_NAME		"proto3"
+#define PATTERN_NAME		"pattern"
+
+#define LANGUAGEDIR			"languages"
+
 #endif /* _TYPES_H_ */
