@@ -13,7 +13,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
@@ -34,26 +34,7 @@ extern struct _xneur_config *xconfig;
 
 void show_notify(int notify, char *command)
 {
-	if (command == NULL) 
-	{
-		command = "\0";
-	}
-
 	play_file(notify);
-
-	if (xconfig->osds[notify].file != NULL)
-	{
-		char *buffer = (char *) malloc((strlen(xconfig->osds[notify].file) + strlen(command) + 2) * sizeof(char));
-		sprintf(buffer, "%s %s", xconfig->osds[notify].file, command);
-
-		osd_show(buffer);
-	}
-
-	if (xconfig->popups[notify].file != NULL)
-	{
-		char *buffer = (char *) malloc((strlen(xconfig->osds[notify].file) + strlen(command) + 2) * sizeof(char));
-		sprintf(buffer, "%s %s", xconfig->popups[notify].file, command);
-
-		popup_show(buffer);
-	}
+	popup_show(notify, command);
+	osd_show(notify, command);
 }
