@@ -13,13 +13,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
 #ifndef _OSD_H_
 #define _OSD_H_
 
-void osd_show(char *osd_text);
+void osd_show(int notify, char *command);
 
 #endif /* _OSD_H_ */
