@@ -13,13 +13,21 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- *  Copyright (C) 2006-2009 XNeur Team
+ *  Copyright (C) 2006-2012 XNeur Team
  *
  */
 
 #ifndef _POPUP_H_
 #define _POPUP_H_
 
-void popup_show(char *popup_text);
+struct _popup_body
+{
+	char *header;
+	char *content;
+};
+
+void popup_init(void);
+void popup_show(int notify, char *command);
+void popup_uninit(void);
 
 #endif /* _POPUP_H_ */
